var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
/*
 * Pelion Device Management JavaScript SDK
 * Copyright Arm Limited 2017
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { union } from "../../../common/utils";
import { ensureArray, matchWithWildcard } from "../../../legacy/common/functions";
import { presubscriptionsEqual, } from "../../../legacy/connect/types";
import { Observer } from "./observer";
export class ResourceValuesObserver extends Observer {
    constructor(_filter, _connect, firstValue = "OnValueUpdate") {
        super();
        this.firstValue = firstValue;
        this.localPresubscriptions = new Array();
        if (_connect) {
            this.connect = _connect;
        }
        if (_filter) {
            this.filter = _filter;
            // create presubscriptions
            ensureArray(this.filter.deviceId).forEach(d => {
                this.localPresubscriptions.push({
                    deviceId: d,
                    resourcePaths: this.filter.resourcePaths || new Array(),
                });
            });
        }
    }
    /**
     * Notify this observer
     * @param data
     */
    notify(data) {
        if (this.subscribed) {
            if (this.localPresubscriptions.length === 0) {
                super.notify(data);
            }
            if (this.compareData(data)) {
                super.notify(data);
            }
        }
    }
    /**
     * Stop this observer from recieving notifications
     */
    unsubscribe() {
        this.subscribed = false;
        super.clearListeners();
    }
    compareData(data) {
        return this.localPresubscriptions.some(sub => {
            return (matchWithWildcard(sub.deviceId, data.deviceId) &&
                (sub.resourcePaths.length === 0 || sub.resourcePaths.some(r => matchWithWildcard(r, data.path))));
        });
    }
    syncPresubscriptions() {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
        return __awaiter(this, void 0, void 0, function* () {
            (_b = (_a = this.connect) === null || _a === void 0 ? void 0 : _a._log) === null || _b === void 0 ? void 0 : _b.debug("syncing subscriptions...");
            const serverPresubscriptions = yield ((_c = this.connect) === null || _c === void 0 ? void 0 : _c.listPresubscriptions());
            yield ((_d = this.connect) === null || _d === void 0 ? void 0 : _d.updatePresubscriptions(this.unionOfPresubscriptions(serverPresubscriptions, this.localPresubscriptions)));
            if (this.firstValue === "OnValueUpdate") {
                const connectedDevices = (_f = (yield ((_e = this.connect) === null || _e === void 0 ? void 0 : _e.listConnectedDevices()))) === null || _f === void 0 ? void 0 : _f.data;
                for (const p of this.localPresubscriptions) {
                    const matchingDevices = (_g = connectedDevices === null || connectedDevices === void 0 ? void 0 : connectedDevices.filter(device => matchWithWildcard(device.id, p.deviceId))) !== null && _g !== void 0 ? _g : [];
                    for (const m of matchingDevices) {
                        const resources = yield m.listResources();
                        for (const q of resources) {
                            if (p.resourcePaths.length === 0 || p.resourcePaths.some(w => matchWithWildcard(w, q.path))) {
                                if (q.observable) {
                                    try {
                                        yield ((_h = this.connect) === null || _h === void 0 ? void 0 : _h.addResourceSubscription(m.id, q.path));
                                    }
                                    catch (e) {
                                        (_k = (_j = this.connect) === null || _j === void 0 ? void 0 : _j._log) === null || _k === void 0 ? void 0 : _k.error(`failed to create subscription for ${m.id} ${q.path}`);
                                    }
                                }
                            }
                        }
                    }
                }
            }
            return;
        });
    }
    unionOfPresubscriptions(server, local) {
        return union(server, local, presubscriptionsEqual);
    }
}
//# sourceMappingURL=resourceValuesObserver.js.map